@@ -1,6 +1,5 @@
 package POEx::Role::TCPClient;
-our $VERSION = '0.092340';
-
+our $VERSION = '0.100170';
 
 #ABSTRACT: A Moose Role that provides TCPClient behavior
 
@@ -9,7 +8,6 @@ use MooseX::Declare;
 role POEx::Role::TCPClient 
 {
     with 'POEx::Role::SessionInstantiation';
-    use MooseX::AttributeHelpers;
     use POEx::Types(':all');
     use MooseX::Types::Moose(':all');
     use POE::Wheel::ReadWrite;
@@ -24,36 +22,36 @@ role POEx::Role::TCPClient
 
     has socket_factories =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
         isa         => HashRef[Object],
+        traits      => ['Hash'],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_socket_factories',
-        provides    =>
+        handles     =>
         {
-            get     => 'get_socket_factory',
-            set     => 'set_socket_factory',
-            delete  => 'delete_socket_factory',
-            count   => 'has_socket_factories',
-            exists  => 'has_socket_factory',
+            'get_socket_factory'       => 'get',
+            'set_socket_factory'       => 'set',
+            'delete_socket_factory'    => 'delete',
+            'has_socket_factories'     => 'count',
+            'has_socket_factory'       => 'exists',
         }
     );
 
 
     has wheels =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
         isa         => HashRef[Object],
+        traits      => ['Hash'],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_wheels',
-        provides    =>
+        handles    =>
         {
-            get     => 'get_wheel',
-            set     => 'set_wheel',
-            delete  => 'delete_wheel',
-            count   => 'count_wheels',
-            exists  => 'has_wheel',
+            'get_wheel'    => 'get',
+            'set_wheel'    => 'set',
+            'delete_wheel' => 'delete',
+            'count_wheels' => 'count',
+            'has_wheel'    => 'exists',
         }
     );
 
@@ -75,18 +73,18 @@ role POEx::Role::TCPClient
 
     has connection_tags =>
     (
-        metaclass   => 'MooseX::AttributeHelpers::Collection::Hash',
         isa         => HashRef[Ref],
+        traits      => ['Hash'],
         lazy        => 1,
         default     => sub { {} },
         clearer     => 'clear_connection_tags',
-        provides    =>
+        handles     =>
         {
-            get     => 'get_connection_tag',
-            set     => 'set_connection_tag',
-            delete  => 'delete_connection_tag',
-            count   => 'has_connection_tags',
-            exists  => 'has_connection_tag',
+            'get_connection_tag'       => 'get',
+            'set_connection_tag'       => 'set',
+            'delete_connection_tag'    => 'delete',
+            'has_connection_tags'      => 'count',
+            'has_connection_tag'       => 'exists',
         }
 
     );
@@ -151,7 +149,6 @@ role POEx::Role::TCPClient
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -160,7 +157,7 @@ POEx::Role::TCPClient - A Moose Role that provides TCPClient behavior
 
 =head1 VERSION
 
-version 0.092340
+version 0.100170
 
 =head1 REQUIRES
 
@@ -171,7 +168,121 @@ version 0.092340
 This required method will be passed the data received, and from which wheel 
 it came. 
 
+=cut
 
+=pod
+
+=head1 ATTRIBUTES
+
+=head2 socket_factories traits: ['Hash'], isa: HashRef[Object]
+
+The POE::Wheel::SocketFactory objects created in connect are stored here and 
+managed via the following provides:
+
+    handles     =>
+    {
+        'get_socket_factory'       => 'get',
+        'set_socket_factory'       => 'set',
+        'delete_socket_factory'    => 'delete',
+        'has_socket_factories'     => 'count',
+        'has_socket_factory'       => 'exists',
+    }
+
+=cut
+
+=pod
+
+=head2 wheels traits: ['Hash'], isa: HashRef, clearer: clear_wheels
+
+When connections are finished, a POE::Wheel::ReadWrite object is created and 
+stored in this attribute, keyed by WheelID. Wheels may be accessed via the
+following provided methods. 
+
+    handles    =>
+    {
+        'get_wheel'    => 'get',
+        'set_wheel'    => 'set',
+        'delete_wheel' => 'delete',
+        'count_wheels' => 'count',
+        'has_wheel'    => 'exists',
+    }
+
+=cut
+
+=pod
+
+=head2 last_wheel is: rw, isa: WheelID
+
+This holds the last ID created from the handle_on_connect method. Handy if the
+protocol requires client initiation.
+
+=cut
+
+=pod
+
+=head2 filter is: rw, isa: Filter
+
+This stores the filter that is used when constructing wheels. It will be cloned
+for each connection completed.
+
+=cut
+
+=pod
+
+=head2 connection_tags metaclass: Collection::Hash, is: ro, isa: HashRef[Ref]
+
+This stores any arbitrary user data passed to connect keyed by the socket
+factory ID. Handy to match up multiple connects for composers.
+
+=cut
+
+=pod
+
+=head1 METHODS
+
+=head2 connect(Str :$remote_address, Int :$remote_port, Ref :$tag?) is Event
+
+connect is used to initiate a connection to a remote source. It accepts two 
+named arguments that both required, remote_address and remote_port. They are 
+passed directly to SocketFactory. If tag is provided, it will be stored in 
+connection_tags and keyed by the socket factory's ID.
+
+=cut
+
+=pod
+
+=head2 handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
+
+handle_on_connect is the SuccessEvent of the SocketFactory instantiated in _start. 
+
+=cut
+
+=pod
+
+=head2 handle_connect_error(Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_connect_error is the FailureEvent of the SocketFactory
+
+=cut
+
+=pod
+
+=head2 handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event
+
+handle_socket_error is the ErrorEvent of each POE::Wheel::ReadWrite instantiated.
+
+=cut
+
+=pod
+
+=head2 shutdown() is Event
+
+shutdown unequivically terminates the TCPClient by clearing all wheels and 
+aliases, forcing POE to garbage collect the session.
+
+=cut
+
+=pod
 
 =head1 DESCRIPTION
 
@@ -188,120 +299,19 @@ handle_inbound_data.
 
 The connect event must be invoked to initiate a connection.
 
-=head1 ATTRIBUTES
-
-=head2 socket_factories metaclass: Collection::Hash, isa: HashRef[Object]
-
-The POE::Wheel::SocketFactory objects created in connect are stored here and 
-managed via the following provides:
-
-    provides    =>
-    {
-        get     => 'get_socket_factory',
-        set     => 'set_socket_factory',
-        delete  => 'delete_socket_factory',
-        count   => 'has_socket_factories',
-        exists  => 'has_socket_factory',
-    }
-
-
-
-=head2 wheels metaclass: Collection::Hash, isa: HashRef, clearer: clear_wheels
-
-When connections are finished, a POE::Wheel::ReadWrite object is created and 
-stored in this attribute, keyed by WheelID. Wheels may be accessed via the
-following provided methods. See MooseX::AttributeHelpers::Collection::Hash
-for more details.
-
-    provides    =>
-    {
-        get     => 'get_wheel',
-        set     => 'set_wheel',
-        delete  => 'delete_wheel',
-        count   => 'count_wheels',
-        exists  => 'has_wheel',
-    }
-
-
-
-=head2 last_wheel is: rw, isa: WheelID
-
-This holds the last ID created from the handle_on_connect method. Handy if the
-protocol requires client initiation.
-
-
-
-=head2 filter is: rw, isa: Filter
-
-This stores the filter that is used when constructing wheels. It will be cloned
-for each connection completed.
-
-
-
-=head2 connection_tags metaclass: Collection::Hash, is: ro, isa: HashRef[Ref]
-
-This stores any arbitrary user data passed to connect keyed by the socket
-factory ID. Handy to match up multiple connects for composers.
-
-    provides    =>
-    {
-        get     => 'get_connection_tag',
-        set     => 'set_connection_tag',
-        delete  => 'delete_connection_tag',
-        count   => 'has_connection_tags',
-        exists  => 'has_connection_tag',
-    }
-
-
-
-=head2 connect(Str :$remote_address, Int :$remote_port, Ref :$tag?) is Event
-
-connect is used to initiate a connection to a remote source. It accepts two 
-named arguments that both required, remote_address and remote_port. They are 
-passed directly to SocketFactory. If tag is provided, it will be stored in 
-connection_tags and keyed by the socket factory's ID.
-
-
-
-=head2 handle_on_connect(GlobRef $socket, Str $address, Int $port, WheelID $id) is Event
-
-handle_on_connect is the SuccessEvent of the SocketFactory instantiated in _start. 
-
-
-
-=head2 handle_connect_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-handle_connect_error is the FailureEvent of the SocketFactory
-
-
-
-=head2 handle_socket_error(Str $action, Int $code, Str $message, WheelID $id) is Event
-
-handle_socket_error is the ErrorEvent of each POE::Wheel::ReadWrite instantiated.
-
-
-
-=head2 shutdown() is Event
-
-shutdown unequivically terminates the TCPClient by clearing all wheels and 
-aliases, forcing POE to garbage collect the session.
-
-
-
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+Nicholas Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2009 by Nicholas Perez.
+This software is Copyright (c) 2010 by Nicholas Perez.
 
 This is free software, licensed under:
 
   The GNU General Public License, Version 3, June 2007
 
-=cut 
-
+=cut
 
 
 __END__
